@@ -1,4 +1,4 @@
-/* $Id: Flx.c,v 1.74 2006/04/04 12:32:42 kb Exp $
+/* $Id: Flx.c,v 1.74.2.1 2007/03/22 22:46:18 bill Exp $
 
 Copyright (C) 2004  The PARI group.
 
@@ -1383,7 +1383,7 @@ Flxq_pow(GEN x, GEN n, GEN pol, ulong p)
   pari_sp av = avma;
   Flxq_muldata D;
   GEN y;
-  if (!signe(n)) return Fl_to_Flx(1,varn(pol));
+  if (!signe(n)) return Fl_to_Flx(1,pol[1]);
   if (signe(n) < 0)
     x=Flxq_inv(x,pol,p);
   else
