@@ -1,4 +1,4 @@
-/* $Id: alglin1.c,v 1.211.2.1 2007/02/13 22:29:19 kb Exp $
+/* $Id: alglin1.c,v 1.211.2.2 2007-12-14 21:54:34 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -2901,18 +2901,18 @@ FpM_gauss_pivot(GEN x, GEN p, GEN *dd, long *rr)
       for (i=k+1; i<=n; i++)
 	gcoeff(x,j,i) = modii(mulii(piv,gcoeff(x,j,i)), p);
       for (t=1; t<=m; t++)
-        if (!c[t]) /* no pivot on that line yet */
-        {
-          piv=gcoeff(x,t,k);
-          if (signe(piv))
-          {
-            gcoeff(x,t,k) = gen_0;
-            for (i=k+1; i<=n; i++)
-              gcoeff(x,t,i) = addii(gcoeff(x,t,i), mulii(piv,gcoeff(x,j,i)));
-            if (low_stack(lim, stack_lim(av,1)))
-              gerepile_gauss(x,k,t,av,j,c);
-          }
-        }
+      {
+        if (c[t]) continue; /* already a pivot on that line */
+
+        piv = modii(gcoeff(x,t,k), p);
+        if (!signe(piv)) continue;
+
+        gcoeff(x,t,k) = gen_0;
+        for (i=k+1; i<=n; i++)
+          gcoeff(x,t,i) = addii(gcoeff(x,t,i), mulii(piv,gcoeff(x,j,i)));
+        if (low_stack(lim, stack_lim(av,1)))
+          gerepile_gauss(x,k,t,av,j,c);
+      }
       for (i=k; i<=n; i++) gcoeff(x,j,i) = gen_0; /* dummy */
     }
   }
@@ -2947,18 +2947,18 @@ FqM_gauss_pivot(GEN x, GEN T, GEN p, GEN *dd, long *rr)
       for (i=k+1; i<=n; i++)
 	gcoeff(x,j,i) = Fq_mul(piv,gcoeff(x,j,i), T, p);
       for (t=1; t<=m; t++)
-        if (!c[t]) /* no pivot on that line yet */
-        {
-          piv=gcoeff(x,t,k);
-          if (signe(piv))
-          {
-            gcoeff(x,t,k) = gen_0;
-            for (i=k+1; i<=n; i++)
-              gcoeff(x,t,i) = gadd(gcoeff(x,t,i), gmul(piv,gcoeff(x,j,i)));
-            if (low_stack(lim, stack_lim(av,1)))
-              gerepile_gauss(x,k,t,av,j,c);
-          }
-        }
+      {
+        if (c[t]) continue; /* already a pivot on that line */
+
+        piv = Fq_red(gcoeff(x,t,k), T,p);
+        if (!signe(piv)) continue;
+
+        gcoeff(x,t,k) = gen_0;
+        for (i=k+1; i<=n; i++)
+          gcoeff(x,t,i) = gadd(gcoeff(x,t,i), gmul(piv,gcoeff(x,j,i)));
+        if (low_stack(lim, stack_lim(av,1)))
+          gerepile_gauss(x,k,t,av,j,c);
+      }
       for (i=k; i<=n; i++) gcoeff(x,j,i) = gen_0; /* dummy */
     }
   }
