@@ -1,4 +1,4 @@
-/* $Id: arith2.c,v 1.135 2006/04/08 10:48:32 kb Exp $
+/* $Id: arith2.c,v 1.135.2.1 2007/04/03 12:24:25 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -1702,7 +1702,7 @@ ibitxor(GEN x, GEN y)
 GEN
 ibitnegimply(GEN x, GEN y)
 {
-  long lx, ly, lout, lin;
+  long lx, ly, lin;
   long *xp, *yp, *outp;
   GEN out;
   long i;
@@ -1711,9 +1711,8 @@ ibitnegimply(GEN x, GEN y)
 
   lx = lgefint(x); xp = int_LSW(x);
   ly = lgefint(y); yp = int_LSW(y);
-  if (lx < ly) { lin = lx; lout = ly; } else { lin = ly; lout = lx; }
-  /* lout > 2 */
-  out = cgeti(lout); out[1] = evalsigne(1) | evallgefint(lout);
+  lin = min(lx,ly);
+  out = cgeti(lx); out[1] = evalsigne(1) | evallgefint(lx);
   outp = int_LSW(out);
   for (i=2; i<lin; i++)
   {
@@ -1728,12 +1727,6 @@ ibitnegimply(GEN x, GEN y)
     outp  = int_nextW(outp);
     xp    = int_nextW(xp);
   }
-  for (   ;i<ly;i++)
-  {
-    *outp = ~(*yp);
-    outp  = int_nextW(outp);
-    yp    = int_nextW(yp);
-  }
   if ( !*int_MSW(out) ) out = int_normalize(out, 1);
   return out;
 }
