@@ -1,4 +1,4 @@
-/* $Id: base1.c,v 1.248 2006/04/08 12:11:16 kb Exp $
+/* $Id: base1.c,v 1.248.2.2 2007/03/11 22:48:52 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -1169,7 +1169,7 @@ nfbasic_to_nf(nfbasic_t *T, GEN ro, long prec)
 {
   GEN nf = cgetg(10,t_VEC);
   GEN x = T->x;
-  GEN invbas, Tr, D, TI, A, dA, MDI, mat = cgetg(8,t_VEC);
+  GEN absdK, invbas, Tr, D, TI, A, dA, MDI, mat = cgetg(8,t_VEC);
   nffp_t F;
   get_nf_fp_compo(T, &F, ro, prec);
 
@@ -1190,10 +1190,11 @@ nfbasic_to_nf(nfbasic_t *T, GEN ro, long prec)
   if (DEBUGLEVEL) msgtimer("mult. table");
 
   Tr = get_Tr(gel(nf,9), x, F.basden);
-  TI = ZM_inv(Tr, T->dK); /* dK T^-1 */
+  absdK = T->dK; if (signe(absdK) < 0) absdK = negi(absdK);
+  TI = ZM_inv(Tr, absdK); /* dK T^-1 */
   A = Q_primitive_part(TI, &dA);
   gel(mat,6) = A; /* primitive part of codifferent, dA its denominator */
-  dA = dA? diviiexact(T->dK, dA): T->dK;
+  dA = dA? diviiexact(absdK, dA): absdK;
   A = hnfmodid(A, dA);
   MDI = ideal_two_elt(nf, A);
   gel(MDI,2) = eltmul_get_table(nf, gel(MDI,2));
@@ -1876,40 +1877,49 @@ chk_gen_init(FP_chk_fun *chk, GEN R, GEN U)
     }
   }
 
-  inv = ginv( split_realimag(d->ZKembed, r1, r2) ); /*TODO: use QR?*/
-  V = cgetg(N+1, t_VEC);
-  M = cgetg(1, t_MAT);
-  for (i = 1; i <= N; i++)
-  { /* M = Q-basis of subfield generated by nf.zk[1..i-1] */
-    GEN Mx, M2;
-    long j, k, h, rkM, dP = S[i];
+  if (firstprim > 1)
+  {
+    inv = ginv( split_realimag(d->ZKembed, r1, r2) ); /*TODO: use QR?*/
+    V = gel(inv,1);
+    for (i = 2; i <= r1+r2; i++) V = gadd(V, gel(inv,i)); 
+    /* V corresponds to 1_Z */
+    V = grndtoi(V, &j);
+    if (j > -5) err(bugparier,"precision too low in chk_gen_init");
+    M = mkmat(V); /* 1 */
 
-    if (dP == N) break; /* primitive */
-    Mx = set_mulid(V, d->ZKembed, inv, r1, r2, N, i);
-    if (!Mx) break; /* prec. problem. Stop */
-    rkM = lg(M)-1;
-    if (dP == 1 && !rkM) M = mkmat(col_ei(N, 1));
-    M2 = cgetg(N+1, t_MAT); /* we will add to M the elts of M2 */
-    gel(M2,1) = col_ei(N, i); /* nf.zk[i] */
-    k = 2;
-    for (h = 1; h < dP; h++)
-    { 
-      long r; /* add to M2 the elts of M * nf.zk[i]  */
-      for (j = 1; j <= rkM; j++) gel(M2,k++) = gmul(Mx, gel(M,j));
-      setlg(M2, k); k = 1;
-      M = image(shallowconcat(M, M2));
-      r = lg(M) - 1;
-      if (r == rkM) break;
-      if (r > rkM)
-      {
-        rkM = r;
-        if (rkM == N) break;
+    V = cgetg(N+1, t_VEC);
+    for (i = 1; i <= N; i++)
+    { /* M = Q-basis of subfield generated by nf.zk[1..i-1] */
+      GEN Mx, M2;
+      long j, k, h, rkM, dP = S[i];
+
+      if (dP == N) break; /* primitive */
+      Mx = set_mulid(V, d->ZKembed, inv, r1, r2, N, i);
+      if (!Mx) break; /* prec. problem. Stop */
+      if (dP == 1) continue;
+      rkM = lg(M)-1;
+      M2 = cgetg(N+1, t_MAT); /* we will add to M the elts of M2 */
+      gel(M2,1) = col_ei(N, i); /* nf.zk[i] */
+      k = 2;
+      for (h = 1; h < dP; h++)
+      { 
+        long r; /* add to M2 the elts of M * nf.zk[i]  */
+        for (j = 1; j <= rkM; j++) gel(M2,k++) = gmul(Mx, gel(M,j));
+        setlg(M2, k); k = 1;
+        M = image(shallowconcat(M, M2));
+        r = lg(M) - 1;
+        if (r == rkM) break;
+        if (r > rkM)
+        {
+          rkM = r;
+          if (rkM == N) break;
+        }
       }
-    }
-    if (rkM == N) break;
+      if (rkM == N) break;
 
-    /* Q(w[1],...,w[i-1]) is a strict subfield of nf */
-    skipfirst++;
+      /* Q(w[1],...,w[i-1]) is a strict subfield of nf */
+      skipfirst++;
+    }
   }
   /* x_1,...,x_skipfirst generate a strict subfield [unless N=skipfirst=1] */
   chk->skipfirst = skipfirst;
