@@ -1,4 +1,4 @@
-/* $Id: base4.c,v 1.241 2006/04/08 12:11:16 kb Exp $
+/* $Id: base4.c,v 1.241.2.2 2007/05/10 16:20:04 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -2050,7 +2050,7 @@ ideallllred(GEN nf, GEN I, GEN vdir, long prec)
     if (!aI) return I;
     goto END;
   }
-  if (typ(I) != id_MAT || lg(I) != N+1) I = idealhermite_aux(nf,I);
+  if (typ(I) != t_MAT || lg(I) != N+1) I = idealhermite_aux(nf,I);
   I = Q_primitive_part(I, &c1);
   y = ideallllred_elt(nf, I, vdir);
 
@@ -2556,8 +2556,7 @@ GEN
 element_reduce(GEN nf, GEN x, GEN ideal)
 {
   pari_sp av = avma;
-  long tx = typ(x);
-  if (is_extscalar_t(tx)) x = poltobasis(checknf(nf), x);
+  x = algtobasis_i(checknf(nf), x);
   return gerepileupto(av, reducemodinvertible(x, ideal));
 }
 /* Given an element x and an ideal in matrix form (not necessarily HNF),
