@@ -1,4 +1,4 @@
-/* $Id: gen1.c,v 1.176.2.1 2006/08/03 17:25:19 kb Exp $
+/* $Id: gen1.c,v 1.176.2.3 2007/05/02 21:06:24 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -275,14 +275,9 @@ gred_rfrac2_i(GEN n, GEN d)
   n = simplify_i(n);
   if (isexactzero(n)) return gcopy(n);
   d = simplify_i(d);
-  tn = typ(n);
   td = typ(d);
-  if (td!=t_POL)
-  {
-    if (tn!=t_POL) return gdiv(n,d);
-    if (varncmp(gvar2(d), varn(n)) > 0) return RgX_Rg_div(n,d);
-    pari_err(talker,"incompatible variables in gred");
-  }
+  if (td!=t_POL || varncmp(varn(d), gvar(n)) > 0) return gdiv(n,d);
+  tn = typ(n);
   if (tn!=t_POL)
   {
     if (varncmp(varn(d), gvar2(n)) < 0) return gred_rfrac_simple(n,d);
@@ -1216,39 +1211,35 @@ GEN
 mulcxI(GEN x)
 {
   GEN z;
-  if (typ(x) != t_COMPLEX)
+  switch(typ(x))
   {
-    z = cgetg(3,t_COMPLEX);
-    gel(z,1) = gen_0;
-    gel(z,2) = x;
+    case t_INT: case t_REAL: case t_FRAC:
+      return mkcomplex(gen_0, x);
+    case t_COMPLEX:
+      if (isexactzero(gel(x,1))) return gneg(gel(x,2));
+      z = cgetg(3,t_COMPLEX);
+      gel(z,1) = gneg(gel(x,2));
+      z[2] = x[1]; return z;
+    default:
+      return gmul(gi, x);
   }
-  else
-  {
-    if (isexactzero(gel(x,1))) return gneg(gel(x,2));
-    z = cgetg(3,t_COMPLEX);
-    gel(z,1) = gneg(gel(x,2));
-    z[2] = x[1];
-  }
-  return z;
 }
 GEN
 mulcxmI(GEN x)
 {
   GEN z;
-  if (typ(x) != t_COMPLEX)
+  switch(typ(x))
   {
-    z = cgetg(3,t_COMPLEX);
-    gel(z,1) = gen_0;
-    gel(z,2) = gneg(x);
+    case t_INT: case t_REAL: case t_FRAC:
+      return mkcomplex(gen_0, gneg(x));
+    case t_COMPLEX:
+      if (isexactzero(gel(x,1))) return gel(x,2);
+      z = cgetg(3,t_COMPLEX);
+      z[1] = x[2];
+      gel(z,2) = gneg(gel(x,1)); return z;
+    default:
+      return gmul(mkcomplex(gen_0, gen_m1), x);
   }
-  else
-  {
-    if (isexactzero(gel(x,1))) return gel(x,2);
-    z = cgetg(3,t_COMPLEX);
-    z[1] = x[2];
-    gel(z,2) = gneg(gel(x,1));
-  }
-  return z;
 }
 
 GEN
