@@ -1,4 +1,4 @@
-/* $Id: polarit1.c,v 1.268.2.3 2006/12/13 22:33:01 kb Exp $
+/* $Id: polarit1.c,v 1.268.2.5 2007-12-02 11:20:18 kb Exp $
 
 Copyright (C) 2000-2004  The PARI group.
 
@@ -291,10 +291,11 @@ FpX_roots_i(GEN f, GEN p)
   da = degpol(f);
   if (da == 1) { gel(y,j++) = subii(p, gel(f,2)); setlg(y,j); return y; }
   if (da == 2) {
-    GEN r = FpX_quad_root(f, p, 1);
+    GEN s, r = FpX_quad_root(f, p, 1);
     if (r) {
       gel(y, j++) = r;
-      gel(y, j++) = otherroot(f,r, p);
+      s = otherroot(f,r, p);
+      if (!equalii(r, s)) gel(y, j++) = s;
     }
     setlg(y, j); return sort(y);
   }
@@ -2164,7 +2165,7 @@ polfnf(GEN a, GEN T)
   unt = mkpolmod(gen_1,T);
   G = nfgcd(A,derivpol(A), T, dent);
   sqfree = gcmp1(G);
-  u = sqfree? A: RgXQX_div(A, G, T);
+  u = sqfree? A: Q_primpart(RgXQX_div(A, G, T));
   k = 0; n = ZY_ZXY_rnfequation(T, u, &k);
   if (DEBUGLEVEL>4) fprintferr("polfnf: choosing k = %ld\n",k);
   if (!sqfree)
