@@ -1,4 +1,4 @@
-/* $Id: trans1.c,v 1.211.2.5 2007/03/27 15:07:03 kb Exp $
+/* $Id: trans1.c,v 1.211.2.7 2007-10-29 10:26:09 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -1489,7 +1489,7 @@ agm1cx(GEN x, long prec)
   long L, l = precision(x); if (!l) l = prec;
 
   L = 5-bit_accuracy(l);
-  a1 = gmul2n(gadd(real_1(l), x), -1);
+  a1 = gtofp(gmul2n(gadd(real_1(l), x), -1), l); /* avoid loss of accuracy */
   av2 = avma;
   b1 = gsqrt(x, prec);
   while (agmcx_gap(a1,b1,L))
@@ -1513,6 +1513,10 @@ agm1(GEN x, long prec)
   if (gcmp0(x)) return gcopy(x);
   switch(typ(x))
   {
+    case t_INT:
+      if (!is_pm1(x)) break;
+      return (signe(x) > 0)? real_1(prec): real_0(prec);
+
     case t_REAL: return signe(x) > 0? agm1r_abs(x): agm1cx(x, prec);
 
     case t_COMPLEX:
@@ -2159,9 +2163,9 @@ gsincos(GEN x, GEN *s, GEN *c, long prec)
   switch(typ(x))
   {
     case t_INT: case t_FRAC:
-      *s = gtofp(x, prec);
+      *s = cgetr(prec);
       *c = cgetr(prec); av = avma;
-      mpsincos(*s, &ps, &pc);
+      mpsincos(tofp_safe(x, prec), &ps, &pc);
       affr_fixlg(ps,*s);
       affr_fixlg(pc,*c); avma = av; return;
 
