@@ -1,4 +1,4 @@
-/* $Id: trans3.c,v 1.180.2.1 2007/02/14 00:30:13 kb Exp $
+/* $Id: trans3.c,v 1.180.2.3 2007-10-29 10:40:48 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -303,7 +303,8 @@ kbessel(GEN nu, GEN gx, long prec)
 	gmulz(d,c,d);
 	gaddz(e,gmul(d,u),e); p1=gmul(d,v);
 	gaddz(f,p1,f);
-	if (gexpo(p1) - gexpo(f) <= 1-bit_accuracy(precision(p1))) break;
+	if (gcmp0(p1) || gexpo(p1) - gexpo(f) <= 1-bit_accuracy(precision(p1)))
+	  break;
 	avma=av1;
       }
       p1=u; u=e; e=p1;
@@ -606,7 +607,7 @@ hyperu(GEN a, GEN b, GEN gx, long prec)
 	gmulz(d,c,d);
 	gaddz(e,gmul(d,u),e); p1=gmul(d,v);
 	gaddz(f,p1,f);
-	if (gexpo(p1) - gexpo(f) <= 1-bit_accuracy(precision(p1))) break;
+	if (gcmp0(p1) || gexpo(p1) - gexpo(f) <= 1-bit_accuracy(precision(p1))) break;
 	avma=av2;
       }
       p1=u; u=e; e=p1;
@@ -1819,29 +1820,37 @@ cxpolylog(long m, GEN x, long prec)
   long li, i, n, bern_upto;
   pari_sp av=avma;
   GEN p1,z,h,q,s;
+  int real;
 
   if (gcmp1(x)) return szeta(m,prec);
-  z=glog(x,prec); h=gneg_i(glog(gneg_i(z),prec));
-  for (i=1; i<m; i++) h = gadd(h, ginv(utoipos(i)));
+  real = typ(x) == t_REAL;
 
-  bern_upto=m+50; mpbern(bern_upto,prec);
-  q=gen_1; s=szeta(m,prec);
+  z = glog(x,prec); h = gen_1;
+  for (i=2; i<m; i++) h = gadd(h, ginv(utoipos(i)));
+  h = gadd(h, gneg_i( glog(gneg_i(z),prec) ));
+
+  bern_upto = m+50; mpbern(bern_upto,prec);
+  q = gen_1; s = szeta(m,prec);
   for (n=1; n<=m+1; n++)
   {
-    q=gdivgs(gmul(q,z),n);
-    s=gadd(s,gmul((n==(m-1))? h: szeta(m-n,prec),q));
+    q = gdivgs(gmul(q,z),n);
+    if (n == m-1) {
+      p1 = gmul(h, q);
+      if (real) p1 = real_i(p1);
+    }
+    else
+      p1 = gmul(szeta(m-n,prec), real? real_i(q): q);
+    s = gadd(s, p1);
   }
 
-  n = m+3; z=gsqr(z); li = -(bit_accuracy(prec)+1);
-
-  for(;;)
+  z = gsqr(z); li = -(bit_accuracy(prec)+1);
+  for(n = m+3;; n += 2)
   {
-    q = gdivgs(gmul(q,z),(n-1)*n);
-    p1 = gmul(szeta(m-n,prec),q);
-    s = gadd(s,p1);
-    if (gexpo(p1) < li) break;
-    n+=2;
-    if (n>=bern_upto) { bern_upto += 50; mpbern(bern_upto,prec); }
+    GEN zet = szeta(m-n,prec);
+    q = divgsns(gmul(q,z), n-1);
+    s = gadd(s, gmul(zet, real? real_i(q): q));
+    if (gexpo(q) + expo(zet) < li) break;
+    if (n >= bern_upto) { bern_upto += 50; mpbern(bern_upto,prec); }
   }
   return gerepileupto(av,s);
 }
