@@ -1,4 +1,4 @@
-/* $Id: gp.c,v 1.290.2.1 2006/09/25 20:35:15 kb Exp $
+/* $Id: gp.c,v 1.290.2.3 2007/06/13 20:50:50 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -793,9 +793,9 @@ gp_quit(void)
 }
 
 static GEN
-gpreadbin(const char *s)
+gpreadbin(const char *s, int *vector)
 {
-  GEN x = readbin(s,infile);
+  GEN x = readbin(s,infile,vector);
   popinfile(); return x;
 }
 
@@ -898,8 +898,9 @@ escape0(char *tch)
       switchin(s);
       if (file_is_binary(infile))
       {
-        GEN x = gpreadbin(s);
-        if (isclone(x)) /* many BIN_GEN */
+        int vector;
+        GEN x = gpreadbin(s, &vector);
+        if (vector) /* many BIN_GEN */
         {
           long i, l = lg(x);
           pari_warn(warner,"setting %ld history entries", l-1);
@@ -1366,7 +1367,7 @@ gp_read_line(filtre_t *F, char *PROMPT)
 {
   Buffer *b = (Buffer*)F->buf;
   int res;
-  if (compatible == OLDALL) F->downcase = 1;
+  F->downcase = (compatible == OLDALL);
   if (b->len > 100000) fix_buffer(b, 100000);
   if (is_interactive())
   {
@@ -1641,7 +1642,10 @@ GEN
 read0(char *s)
 {
   switchin(s);
-  if (file_is_binary(infile)) return gpreadbin(s);
+  if (file_is_binary(infile)) {
+    int junk;
+    return gpreadbin(s, &junk);
+  }
   return gp_main_loop(0);
 }
 
