@@ -1,5 +1,5 @@
 #line 2 "../src/kernel/none/add.c"
-/* $Id: add.c,v 1.13 2006/04/05 16:42:33 kb Exp $
+/* $Id: add.c,v 1.13.2.1 2007/04/18 20:06:59 kb Exp $
 
 Copyright (C) 2002-2003  The PARI group.
 
@@ -20,7 +20,7 @@ static long pos_s[] = {
 
 /* prototype of negative small ints */
 static long neg_s[] = {
-  evaltyp(t_INT) | _evallg(3), evalsigne(-1) | evallgefint(3), 0 };
+  evaltyp(t_INT) | _evallg(3), (long)evalsigne(-1) | evallgefint(3), 0 };
 
 GEN
 addss(long x, long y)
