@@ -1,5 +1,5 @@
 #line 2 "../src/kernel/none/mp.c"
-/* $Id: mp.c,v 1.186 2006/04/04 12:32:43 kb Exp $
+/* $Id: mp.c,v 1.186.2.1 2006/08/24 21:51:50 kb Exp $
 
 Copyright (C) 2000-2003 The PARI group.
 
@@ -1010,9 +1010,10 @@ red_montgomery(GEN T, GEN N, ulong inv)
 
   /* copy result */
   Td = (GEN)av;
-  while (! *scratch) scratch++; /* strip leading zeroes */
+  while (! *scratch && Te > scratch) scratch++; /* strip leading 0s */
   while (Te > scratch) *--Td = *--Te;
-  k = ((GEN)av - Td) + 2;
+  k = (GEN)av - Td; if (!k) return gen_0;
+  k += 2;
   *--Td = evalsigne(1) | evallgefint(k);
   *--Td = evaltyp(t_INT) | evallg(k);
 #ifdef DEBUG
