@@ -1,4 +1,4 @@
-/* $Id: es.c,v 1.222 2006/04/11 15:17:05 kb Exp $
+/* $Id: es.c,v 1.222.2.3 2007-10-29 09:29:20 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -234,8 +234,10 @@ gp_read_file(char *s)
 {
   GEN x = gnil;
   switchin(s);
-  if (file_is_binary(infile))
-    x = readbin(s,infile);
+  if (file_is_binary(infile)) {
+    int junk;
+    x = readbin(s,infile, &junk);
+  }
   else {
     Buffer *b = new_buffer();
     x = gnil;
@@ -277,9 +279,10 @@ gp_readvec_file(char *s)
 {
   GEN x = NULL;
   switchin(s);
-  if (file_is_binary(infile))
-    x = readbin(s,infile);
-  else 
+  if (file_is_binary(infile)) {
+    int junk;
+    x = readbin(s,infile,&junk);
+  } else 
     x = gp_readvec_stream(infile);
   popinfile(); return x;
 }
@@ -418,7 +421,7 @@ pariputs(const char *s) {
 int
 pari_last_was_newline(void) { return last_was_newline; }
 void
-pari_set_last_newline(int last) { last_was_newline = last; };
+pari_set_last_newline(int last) { last_was_newline = last; }
 
 void
 pariflush(void) { pariOut->flush(); }
@@ -3086,7 +3089,7 @@ accept_file(char *name, FILE *file)
     ))
     { /* compressed file (compress or gzip) */
       char *cmd = gpmalloc(strlen(ZCAT) + l + 2);
-      sprintf(cmd,"%s %s",ZCAT,name);
+      sprintf(cmd,"%s \"%s\"",ZCAT,name);
       fclose(file); infile = try_pipe(cmd, mf_IN)->file;
       free(cmd); return infile;
     }
@@ -3380,9 +3383,9 @@ writebin(char *name, GEN x)
 
 /* read all objects in f. If f contains BIN_GEN that would be silently ignored
  * [i.e f contains more than one objet, not all of them 'named GENs'], return
- * them all in a vector with clone bit set (special marker). */
+ * them all in a vector and set 'vector'. */
 GEN
-readbin(const char *name, FILE *f)
+readbin(const char *name, FILE *f, int *vector)
 {
   pari_sp av = avma;
   GEN x,y,z;
@@ -3401,8 +3404,10 @@ readbin(const char *name, FILE *f)
       pari_warn(warner,"%ld unnamed objects read. Returning then in a vector",
           lg(z)-1);
     x = gerepilecopy(av, z);
-    setisclone(x); /* HACK */
+    *vector = 1;
   }
+  else
+    *vector = 0;
   return x;
 }
 
