@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.305.2.1 2006/08/03 16:41:28 kb Exp $
+/* $Id: init.c,v 1.305.2.2 2007-10-29 10:19:39 kb Exp $
 
 Copyright (C) 2000-2003  The PARI group.
 
@@ -1473,6 +1473,14 @@ gclone(GEN x)
   {
     lx = (tx==t_INT)? lgefint(x): lg(x);
     for (i=0; i<lx; i++) y[i] = x[i];
+    if (tx == t_INT) {
+      lx = lgefint(x);
+      y[0] = evaltyp(t_INT)|evallg(lx);
+      for (i=1; i<lx; i++) y[i] = x[i];
+    } else {
+      lx = lg(x);
+      for (i=0; i<lx; i++) y[i] = x[i];
+    }
   }
   else
   {
