@@ -1,4 +1,4 @@
-/* $Id: members.c,v 1.24.2.1 2006/11/16 16:18:31 kb Exp $
+/* $Id: members.c,v 1.24.2.2 2007-10-29 10:33:14 kb Exp $
 
 Copyright (C) 2000-2003  The PARI group.
 
@@ -206,10 +206,12 @@ member_diff(GEN x) /* different */
 GEN
 member_codiff(GEN x) /* codifferent */
 {
-  long t; GEN H, nf = get_nf(x,&t), y = nfmats(nf);
+  long t; GEN T, D, DinvT, nf = get_nf(x,&t), y = nfmats(nf);
   if (!y) member_err("codiff");
-  H = hnf(gel(y,6));
-  return gdiv(H, gcoeff(H,1,1));
+  T = gel(y,4);
+  D = absi(gel(nf,3));
+  DinvT = ZM_inv(T,D);
+  return gdiv(hnfmod(DinvT, D), D);
 }
 
 GEN
