@@ -1,4 +1,4 @@
-/* $Id: sumiter.c,v 1.99.2.1 2006/09/30 10:55:30 kb Exp $
+/* $Id: sumiter.c,v 1.99.2.2 2007/05/07 22:52:01 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -998,7 +998,7 @@ sumpos2(void *E, GEN (*eval)(GEN,void*), GEN a, long prec)
   for (k=1; k<=lg(pol)-2; k++)
   {
     GEN p1 = gmul(gel(pol,k+1),stock[k]);
-    if (odd(k)) p1 = gneg_i(p1);
+    if (!odd(k)) p1 = gneg_i(p1);
     s = gadd(s,p1);
   }
   return gerepileupto(av, gdiv(s,dn));
