@@ -1,4 +1,4 @@
-/* $Id: thue.c,v 1.76.2.1 2007/03/10 00:04:13 kb Exp $
+/* $Id: thue.c,v 1.76.2.2 2007-10-29 10:35:15 kb Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -1191,11 +1191,11 @@ get_unit_1(GEN bnf, GEN *unit)
 
   if (DEBUGLEVEL > 2) fprintferr("looking for a fundamental unit of norm -1\n");
   if (odd(n)) { *unit = gen_m1; return 1; }
-  v = signunits(bnf);
+  v = zsignunits(bnf, NULL, 0);
   for (i = 1; i < lg(v); i++)
   {
     GEN s = sum(gel(v,i), 1, lg(v[i])-1);
-    if (!gcmp0(s)) {
+    if (mpodd(s)) {
       GEN fu = check_units(bnf, "bnfisintnorm");
       *unit = gel(fu,i); return 1;
     }
